Title: [94957] trunk/Source/WebCore
Revision
94957
Author
pfeld...@chromium.org
Date
2011-09-12 08:22:32 -0700 (Mon, 12 Sep 2011)

Log Message

Web Inspector: event dividers do not update timeline boundaries.
https://bugs.webkit.org/show_bug.cgi?id=67932

* inspector/front-end/NetworkPanel.js:
(WebInspector.NetworkLogView.prototype._onLoadEventFired):
(WebInspector.NetworkLogView.prototype._domContentLoadedEventFired):
(WebInspector.NetworkLogView.prototype.refresh):
(WebInspector.NetworkTimeCalculator.prototype.updateBoundariesForEventTime):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (94956 => 94957)


--- trunk/Source/WebCore/ChangeLog	2011-09-12 14:54:30 UTC (rev 94956)
+++ trunk/Source/WebCore/ChangeLog	2011-09-12 15:22:32 UTC (rev 94957)
@@ -1,3 +1,14 @@
+2011-09-12  Pavel Feldman  <pfeld...@google.com>
+
+        Web Inspector: event dividers do not update timeline boundaries.
+        https://bugs.webkit.org/show_bug.cgi?id=67932
+
+        * inspector/front-end/NetworkPanel.js:
+        (WebInspector.NetworkLogView.prototype._onLoadEventFired):
+        (WebInspector.NetworkLogView.prototype._domContentLoadedEventFired):
+        (WebInspector.NetworkLogView.prototype.refresh):
+        (WebInspector.NetworkTimeCalculator.prototype.updateBoundariesForEventTime):
+
 2011-09-12  Kentaro Hara  <hara...@google.com>
 
         Implement a WebKitAnimationEvent constructor for V8

Modified: trunk/Source/WebCore/inspector/front-end/NetworkPanel.js (94956 => 94957)


--- trunk/Source/WebCore/inspector/front-end/NetworkPanel.js	2011-09-12 14:54:30 UTC (rev 94956)
+++ trunk/Source/WebCore/inspector/front-end/NetworkPanel.js	2011-09-12 15:22:32 UTC (rev 94957)
@@ -627,14 +627,15 @@
     _onLoadEventFired: function(event)
     {
         this._mainResourceLoadTime = event.data || -1;
-        // Update the dividers to draw the new line
-        this._updateDividersIfNeeded(true);
+        // Schedule refresh to update boundaries and draw the new line.
+        this._scheduleRefresh(true);
     },
 
     _domContentLoadedEventFired: function(event)
     {
         this._mainResourceDOMContentTime = event.data || -1;
-        this._updateDividersIfNeeded(true);
+        // Schedule refresh to update boundaries and draw the new line.
+        this._scheduleRefresh(true);
     },
 
     wasShown: function()
@@ -661,6 +662,10 @@
         var wasScrolledToLastRow = this._dataGrid.isScrolledToLastRow();
         var staleItemsLength = this._staleResources.length;
         var boundariesChanged = false;
+        if (this.calculator.updateBoundariesForEventTime) {
+            boundariesChanged = this.calculator.updateBoundariesForEventTime(this._mainResourceLoadTime) || boundariesChanged;
+            boundariesChanged = this.calculator.updateBoundariesForEventTime(this._mainResourceDOMContentTime) || boundariesChanged;
+        }
 
         for (var i = 0; i < staleItemsLength; ++i) {
             var resource = this._staleResources[i];
@@ -1670,6 +1675,18 @@
         return 0;
     },
 
+    updateBoundariesForEventTime: function(eventTime)
+    {
+        if (eventTime === -1 || this.startAtZero)
+            return false;
+
+        if (typeof this.maximumBoundary === "undefined" || eventTime > this.maximumBoundary) {
+            this.maximumBoundary = eventTime;
+            return true;
+        }
+        return false;
+    },
+
     computeBarGraphLabels: function(resource)
     {
         var rightLabel = "";
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to